@@ -119,7 +119,7 @@ void VideoControlPage::OnChangeAccuracy(wxCommandEvent& event)
 
 void VideoControlPage::OnChangeVideoSource(wxCommandEvent& event)
 {
-	m_controller.WriteCommand(wxT("set videosource ") + m_videoSourceList->GetValue().Lower());
+	m_controller.WriteCommand(wxT("set videosource ") + utils::tclEscapeWord(m_videoSourceList->GetValue().Lower()));
 }
 
 void VideoControlPage::OnDeInterlace(wxCommandEvent& event)
@@ -410,14 +410,8 @@ void VideoControlPage::SetSliderDefaults()
 void VideoControlPage::OnBrowseScreenShot(wxCommandEvent& event)
 {
 	int countersize = 0;
-	wxString path;
-#ifndef __MOTIF__
-	path = wxT("Screenshot Files(*.png)|*.png;*.PNG|All files|*.*||");
-#else
-	path = wxT("*.*");
-#endif
-
-	wxFileDialog filedlg(this, wxT("Choose file to save screenshot to"), wxT(""), wxT(""), path, wxSAVE);
+	wxString path = wxT("Screenshot Files(*.png)|*.png;*.PNG|All files|*.*||");
+	wxFileDialog filedlg(this, wxT("Choose file to save screenshot to"), wxT(""), wxT(""), path, wxFD_SAVE);
 	if (filedlg.ShowModal() == wxID_OK) {
 		wxString screenshotpath = filedlg.GetPath();
 		screenshotpath = screenshotpath.Left(screenshotpath.Length() - 4); // remove extension
