@@ -36,7 +36,6 @@ openMSXController::openMSXController(wxWindow* target)
 {
 #ifdef __WXMSW__
 	m_launchCounter = 0;
-	m_openMsxRunning = false;
 	m_namedPipeHandle = INVALID_HANDLE_VALUE;
 #else
 	m_openMSXstdin = m_openMSXstdout = m_openMSXstderr = -1;
@@ -169,7 +168,6 @@ void openMSXController::HandleParsedOutput(wxCommandEvent& event)
 			if ((lastCmd[0] != data->name) ||
 			    (lastCmd[1] != data->contents)) {
 				UpdateSetting2(data->name, data->contents);
-				m_appWindow->m_sessionPage->UpdateSessionData();
 			}
 		}
 		break;
@@ -229,7 +227,7 @@ void openMSXController::WriteCommand(
 {
 	if (!m_openMsxRunning) return;
 
-	xmlChar* buffer = xmlEncodeEntitiesReentrant(nullptr, (const xmlChar*)(const char*)(wxConvUTF8.cWX2MB(command)));
+	xmlChar* buffer = xmlEncodeEntitiesReentrant(nullptr, (const xmlChar*)(const char*)(command.mb_str(wxConvUTF8)));
 	if (!buffer) return;
 
 	CommandEntry temp;
@@ -457,7 +455,7 @@ void openMSXController::InitLaunchScript()
 	AddCommand(wxT("set mute"),
 		[&](const wxString& c, const wxString& r) {
 			UpdateSetting(c, r); });
-	AddCommand(wxT("plug cassetteport"),
+	AddCommand(wxT("catch {cassetteplayer}"),
 		[&](const wxString&, const wxString& r) {
 			m_appWindow->m_sessionPage->EnableCassettePort(r); });
 	AddCommand(wxT("cassetteplayer"),
@@ -470,8 +468,6 @@ void openMSXController::InitLaunchScript()
 	AddCommand(wxT("openmsx_update enable status"));
 	AddCommand(wxT(""), // finish launch
 		[&](const wxString&, const wxString&) {
-			m_appWindow->m_sessionPage->AutoPlugCassette();
-			m_appWindow->m_sessionPage->SetCassetteControl();
 			m_appWindow->OpenMSXStarted();
 		});
 
@@ -586,9 +582,18 @@ void openMSXController::InitLaunchScript()
 	AddSetting(wxT("diskb"),
 		[&](const wxString&, const wxString& v) {
 			UpdateCombo(v, wxT("DiskBContents")); });
+	AddSetting(wxT("carta"),
+		[&](const wxString&, const wxString& v) {
+			UpdateCombo(v, wxT("CartAContents")); });
+	AddSetting(wxT("cartb"),
+		[&](const wxString&, const wxString& v) {
+			UpdateCombo(v, wxT("CartBContents")); });
 	AddSetting(wxT("cassetteplayer"),
 		[&](const wxString&, const wxString& v) {
 			UpdateCombo(v, wxT("CassetteContents")); });
+	AddSetting(wxT("hda"),
+		[&](const wxString&, const wxString& v) {
+			UpdateCombo(v, wxT("HardDiskContents")); });
 	AddSetting(wxT("fullscreen"),
 		[&](const wxString&, const wxString& v) {
 			UpdateToggle(v, wxT("FullScreenButton"), S_CONVERT); });
@@ -688,7 +693,7 @@ void openMSXController::UpdateToggle(const wxString& data, const wxString& contr
 			wxCommandEvent event(wxEVT_COMMAND_TOGGLEBUTTON_CLICKED, button->GetId());
 			event.SetInt(active);
 			event.SetEventObject(button);
-			button->ProcessEvent(event);
+			button->GetEventHandler()->ProcessEvent(event);
 		}
 
 		if (flags & S_CONVERT) {
@@ -904,10 +909,9 @@ bool openMSXController::Launch(wxString cmdline)
 	m_parser.reset(new CatapultXMLParser(m_appWindow));
 #ifdef __WXMSW__
 	m_catapultWindow = GetActiveWindow();
-	bool useNamedPipes = DetermenNamedPipeUsage();
-	cmdline += CreateControlParameter(useNamedPipes);
+	cmdline += CreateControlParameter();
 	HANDLE hInputRead, hOutputWrite, hErrorWrite, hErrorRead, hOutputRead;
-	CreatePipes(useNamedPipes, &hInputRead, &hOutputWrite, &hErrorWrite, &hOutputRead, &hErrorRead);
+	CreatePipes(&hInputRead, &hOutputWrite, &hErrorWrite, &hOutputRead, &hErrorRead);
 
 	DWORD dwProcessFlags = CREATE_NO_WINDOW | CREATE_DEFAULT_ERROR_MODE | CREATE_SUSPENDED;
 	WORD wStartupWnd = SW_HIDE;
@@ -922,14 +926,12 @@ bool openMSXController::Launch(wxString cmdline)
 	si.hStdError  = hErrorWrite;
 	si.wShowWindow = wStartupWnd;
 
-	if (useNamedPipes) {
-		// Note: m_pipeName is set by CreateControlParameter().
-		m_namedPipeHandle = CreateNamedPipe(m_pipeName, PIPE_ACCESS_OUTBOUND, PIPE_TYPE_BYTE, 1, 10000, 0, 100, nullptr);
-		if (m_namedPipeHandle == INVALID_HANDLE_VALUE) {
-			wxMessageBox(wxString::Format(
-				wxT("Error creating pipe: %ld"), GetLastError()));
-			return false;
-		}
+	// Note: m_pipeName is set by CreateControlParameter().
+	m_namedPipeHandle = CreateNamedPipe(m_pipeName, PIPE_ACCESS_OUTBOUND, PIPE_TYPE_BYTE, 1, 10000, 0, 100, nullptr);
+	if (m_namedPipeHandle == INVALID_HANDLE_VALUE) {
+		wxMessageBox(wxString::Format(
+			wxT("Error creating pipe: %ld"), GetLastError()));
+		return false;
 	}
 
 	LPTSTR szCmdLine = _tcsdup(cmdline.c_str());
@@ -954,23 +956,18 @@ bool openMSXController::Launch(wxString cmdline)
 
 	::ResumeThread(m_openmsxProcInfo.hThread);
 
-	if (useNamedPipes) {
-		PipeConnectThread *m_connectThread = new PipeConnectThread(m_appWindow);
-		m_connectThread->Create();
-		m_connectThread->SetHandle(m_namedPipeHandle);
-		m_connectThread->Run();
-		m_outputHandle = m_namedPipeHandle;
-	} else {
-		m_openMsxRunning = true;
-		PostLaunch();
-	}
+	PipeConnectThread *m_connectThread = new PipeConnectThread(m_appWindow);
+	m_connectThread->Create();
+	m_connectThread->SetHandle(m_namedPipeHandle);
+	m_connectThread->Run();
+	m_outputHandle = m_namedPipeHandle;
 	m_openMsxRunning = true;
-	CloseHandles(useNamedPipes, m_openmsxProcInfo.hThread, hInputRead, hOutputWrite, hErrorWrite);
+	CloseHandles(m_openmsxProcInfo.hThread, hInputRead, hOutputWrite, hErrorWrite);
 
 	return true;
 #else
 	cmdline += wxT(" -control stdio");
-	if (!execute((const char*)(wxConvUTF8.cWX2MB((cmdline))),
+	if (!execute((const char*)(cmdline.mb_str(wxConvUTF8)),
 	             m_openMSXstdin, m_openMSXstdout, m_openMSXstderr)) {
 		return false;
 	}
@@ -994,46 +991,24 @@ bool openMSXController::Launch(wxString cmdline)
 // windows or linux specific stuff
 #ifdef __WXMSW__
 
-bool openMSXController::DetermenNamedPipeUsage()
-{
-	bool useNamedPipes = false;
-	if (!FORCE_UNNAMED_PIPES) {
-		OSVERSIONINFO info;
-		info.dwOSVersionInfoSize = sizeof (OSVERSIONINFO);
-		if (!GetVersionEx(&info)) {
-			wxMessageBox(wxString::Format(
-				wxT("Error getting system info: %ld "), GetLastError()));
-		} else {
-			if (info.dwPlatformId == VER_PLATFORM_WIN32_NT) {
-				useNamedPipes = true; // nt-based only and only if the user wants it
-			}
-		}
-	}
-	return useNamedPipes;
-}
-
-wxString openMSXController::CreateControlParameter(bool useNamedPipes)
+wxString openMSXController::CreateControlParameter()
 {
 	wxString parameter = wxT(" -control");
 
-	if (useNamedPipes) {
-		m_launchCounter++;
-		m_pipeName = wxString::Format(
-			wxT("\\\\.\\pipe\\Catapult-%u-%lu"), _getpid(), m_launchCounter);
-		parameter += wxT(" pipe:") + m_pipeName.Mid(9);
-	} else {
-		parameter += wxT(" stdio:");
-	}
+	m_launchCounter++;
+	m_pipeName = wxString::Format(
+		wxT("\\\\.\\pipe\\Catapult-%u-%lu"), _getpid(), m_launchCounter);
+	parameter += wxT(" pipe:") + m_pipeName.Mid(9);
 	return parameter;
 }
 
 bool openMSXController::CreatePipes(
-	bool useNamedPipes, HANDLE* input, HANDLE* output, HANDLE* error,
+	HANDLE* input, HANDLE* output, HANDLE* error,
 	HANDLE* outputWrite, HANDLE* errorWrite)
 {
 	HANDLE hOutputReadTmp, hOutputWrite;
 	HANDLE hErrorReadTmp, hErrorWrite;
-	HANDLE hInputRead = 0, hInputWriteTmp, hInputWrite;
+	HANDLE hInputRead = 0;
 	HANDLE hInputHandle = GetStdHandle(STD_INPUT_HANDLE);
 
 	SECURITY_ATTRIBUTES sa;
@@ -1041,25 +1016,6 @@ bool openMSXController::CreatePipes(
 	sa.lpSecurityDescriptor = nullptr;
 	sa.bInheritHandle = TRUE;
 
-	if (!useNamedPipes) {
-		if (!CreatePipe(&hInputRead, &hInputWriteTmp, &sa, 0)) {
-			ShowError(wxT("Error creating pipe for stdin"));
-			return false;
-		}
-		if (!DuplicateHandle(GetCurrentProcess(), hInputWriteTmp,
-		                     GetCurrentProcess(), &hInputWrite, 0,
-		                     FALSE, DUPLICATE_SAME_ACCESS)) {
-			ShowError(wxT("Error Duplicating InputWriteTmp Handle"));
-			return false;
-		}
-		if (!CloseHandle(hInputWriteTmp)) {
-			ShowError(wxT("Error Closing Input Temp Handle"));
-			return false;
-		}
-		m_outputHandle = hInputWrite;
-		hInputHandle = hInputRead;
-	}
-
 	if (!CreatePipe(&hOutputReadTmp, &hOutputWrite, &sa, 0)) {
 		ShowError(wxT("Error creating pipe for stdout"));
 		return false;
@@ -1082,7 +1038,7 @@ void openMSXController::ShowError(const wxString& msg)
 }
 
 void openMSXController::CloseHandles(
-	bool useNamedPipes, HANDLE hThread, HANDLE hInputRead,
+	HANDLE hThread, HANDLE hInputRead,
 	HANDLE hOutputWrite, HANDLE hErrorWrite)
 {
 	if (!CloseHandle(hThread)) {
@@ -1097,12 +1053,6 @@ void openMSXController::CloseHandles(
 		wxMessageBox(wxT("Unable to close Error Write"));
 		return;
 	}
-	if (!useNamedPipes) {
-		if (!CloseHandle(hInputRead)) {
-			wxMessageBox(wxT("Unable to close Input Read"));
-			return;
-		}
-	}
 }
 
 void openMSXController::HandlePipeCreated()
